from __future__ import annotations

SCENARIO_STAGE = "scenario"
GENERATION_STAGE = "generation"
VALIDATION_STAGE = "validation"
RENDER_STAGE = "render"

SCENARIO_PARSE_FAILED = "scenario_parse_failed"
TEMPLATE_NOT_FOUND = "template_not_found"
SLOT_SCHEMA_NOT_FOUND = "slot_schema_not_found"
PROMPT_NOT_FOUND = "prompt_not_found"
PROMPT_RESOURCE_PARSE_ERROR = "prompt_resource_parse_error"
PROMPT_RESOURCE_ACCESS_ERROR = "prompt_resource_access_error"
INVALID_LLM_OUTPUT = "invalid_llm_output"
MISSING_REQUIRED_FIELDS = "missing_required_fields"
INVALID_FIELD_VALUE = "invalid_field_value"
LLM_EXECUTION_FAILED = "llm_execution_failed"
RENDER_FAILED = "render_failed"
