from __future__ import annotations


NEGOTIATION_TEXT_KEY = "https://github.com/a2aproject/telecommunication/extensions/NEGOTIATION-T"
NEGOTIATION_CONTEXT_KEY = "https://github.com/a2aproject/telecommunication/extensions/DATA-NEGOTIATION-T/v1"
TASK_PROMPT_KEY = "https://github.com/a2aproject/telecommunication/extensions/Task-T/v1"
MAX_IN_PROGRESS_NEGOTIATION_ROUND = 8
